X-Original-To: pgsql-performance-postgresql.org@localhost.postgresql.org Received: from localhost (av.hub.org [200.46.204.144]) by postgresql.org (Postfix) with ESMTP id E91489DCC0B for ; Tue, 6 Dec 2005 20:23:06 -0400 (AST) Received: from postgresql.org ([200.46.204.71]) by localhost (av.hub.org [200.46.204.144]) (amavisd-new, port 10024) with ESMTP id 46842-04 for ; Tue, 6 Dec 2005 20:23:08 -0400 (AST) X-Greylist: from auto-whitelisted by SQLgrey- Received: from vms046pub.verizon.net (vms046pub.verizon.net [206.46.252.46]) by postgresql.org (Postfix) with ESMTP id 1EC199DCAA8 for ; Tue, 6 Dec 2005 20:23:03 -0400 (AST) Received: from osgiliath.mathom.us ([70.108.82.27]) by vms046.mailsrvcs.net (Sun Java System Messaging Server 6.2-4.02 (built Sep 9 2005)) with ESMTPA id <0IR300MX5QEH3BH9@vms046.mailsrvcs.net> for pgsql-performance@postgresql.org; Tue, 06 Dec 2005 18:23:06 -0600 (CST) Received: from localhost (localhost [127.0.0.1]) by osgiliath.mathom.us (Postfix) with ESMTP id E912960017B for ; Tue, 06 Dec 2005 19:23:07 -0500 (EST) Received: from osgiliath.mathom.us ([127.0.0.1]) by localhost (osgiliath [127.0.0.1]) (amavisd-new, port 10024) with LMTP id 10395-04 for ; Tue, 06 Dec 2005 19:23:07 -0500 (EST) Received: by osgiliath.mathom.us (Postfix, from userid 1000) id AA808600176; Tue, 06 Dec 2005 19:23:07 -0500 (EST) Date: Tue, 06 Dec 2005 19:23:07 -0500 From: Michael Stone Subject: Re: postgresql performance tuning In-reply-to: To: pgsql-performance@postgresql.org Mail-followup-to: pgsql-performance@postgresql.org Message-id: <20051207002307.GM7330@mathom.us> MIME-version: 1.0 Content-type: text/plain; charset=us-ascii; format=flowed Content-disposition: inline X-Pgp-Fingerprint: 53 FF 38 00 E7 DD 0A 9C 84 52 84 C5 EE DF 7C 88 X-Virus-Scanned: by amavisd-new-20030616-p10 (Debian) at mathom.us References: User-Agent: Mutt/1.5.11 X-Virus-Scanned: by amavisd-new at hub.org X-Spam-Status: No, score=0 required=5 tests=[none] X-Spam-Score: 0 X-Spam-Level: X-Archive-Number: 200512/207 X-Sequence-Number: 16028 On Tue, Dec 06, 2005 at 04:03:22PM -0600, Ameet Kini wrote: >I'm running postgresql v8.0 and my problem is that running vacuum on my >indices are blazing fast (upto 10x faster) AFTER running reindex. For a >table with only 1 index, the time to do a vacuum (without full) went down >from 45 minutes to under 3 minutes. I've also noticed a fairly large increase in vacuum speed after a reindex. (To the point where the reindex + vacuum was faster than just a vacuum.) Mike Stone